@@ -7,15 +7,18 @@ import redis
 client = None
 
 def connect(*args, **kwargs):
-    """ 连接Redis数据库，参数和redis-py的Redis类一样 """
+    """ 
+    连接 Redis 数据库，参数和 redis-py 的 Redis 类一样。
+    """
     global client
     client = redis.Redis(*args, **kwargs)
 
 def get_client():
-    """ 返回OORedis客户端 """
+    """ 
+    返回 OORedis 客户端。
+    """
     global client
 
-    if client is None:
-        connect()
+    if client is None: connect()
 
     return client
