@@ -1,8 +1,5 @@
 # coding: utf-8
 
-from numbers import Integral
-from helper import is_any_instance
-
 class FloatTypeCase:
 
     """ 
@@ -12,17 +9,16 @@ class FloatTypeCase:
     @staticmethod
     def encode(value):
         """
-        接受 float 类型值，否则抛出 TypeError 。 
+        尝试将输入值转换成 float 类型，
+        如果转换失败，抛出 TypeError 。
         """
-        if is_any_instance(value, float, int):
-            return float(value)
-        
-        raise TypeError
+        return float(value)
 
     @staticmethod
     def decode(value):
         """ 
-        尝试将值转换成 float 类型，
+        尝试将输入值转换成 float 类型，
         如果转换失败，抛出 TypeError 。
         """
-        return None if value is None else float(value)
+        if value is not None:
+            return float(value)
